![build_status](https://travis-ci.org/erniejunior/QuadrotorEnvironment.svg?branch=master)

# Installation
You might need to install `python3-dev` because of the numpy-quaternion dependency.
Otherwise
```bash
$ pip3 install quadrotor_environment
```
should do the trick.